==> kaspaliste-0.4.tar.gz: kaspaliste-0.4/kaspaliste/kaspaliste.cpp <==
/***************************************************************************
                       kaspaliste.cpp  -  description
                             -------------------                                         
    begin                : Dieb Aug 17 03:44:15 CEST 1999
                                           
    copyright            : (C) 1999 by Jan Mueller                         
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "kliste.h"
#include <klocale.h>
#include <qmessagebox.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>

int main(int argc, char **argv)
{
  try {

	KAboutData about("kaspaliste", I18N_NOOP("Kaspaliste"), VERSION,
	I18N_NOOP("A Literature Database"), KAboutData::License_GPL,
	"(C) Jan Mller 1999-2001");
	KCmdLineArgs::init(argc, argv, &about);

  KApplication app;

  if (app.isRestored())
  {
    RESTORE(KaspalisteApp);
  }
  else
  {

    KaspalisteApp *kaspaliste = new KaspalisteApp();
    kaspaliste->show();

   }

  return app.exec();


	}	catch(KaspaErr& err) {
    err.print();
    // QMessageBox::warning(0L, i18n("Error"), err.error());
		return 1;
  }	
}

==> kaspaliste-0.96.tar.gz: kaspaliste-0.96/kaspaliste/kaspaliste.cpp <==
/***************************************************************************
                       kaspaliste.cpp  -  description
                             -------------------                                         
    begin                : Dieb Aug 17 03:44:15 CEST 1999
                                           
    copyright            : (C) 1999 by Jan Mueller                         
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "kliste.h"
#include <klocale.h>
#include <qmessagebox.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>

static KCmdLineOptions options[] = {
  {"conn <connection>", I18N_NOOP("Postgresql connection sting."),
   "dbname=kaspaliste"},
  {0,0,0}
};
  

int main(int argc, char **argv)
{
  try {

	KAboutData about("kaspaliste", I18N_NOOP("Kaspaliste"), VERSION,
	I18N_NOOP("A Literature Database"), KAboutData::License_GPL, "(C) Jan Mueller 1999-2004");
	KCmdLineArgs::init(argc, argv, &about);
  KCmdLineArgs::addCmdLineOptions(options);

  KApplication app;
  
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  QString dbname;
  dbname = args->getOption("conn");
  
  if (app.isRestored())
  {
    RESTORE(KaspalisteApp(dbname));
  }
  else
  {
    KaspalisteApp *kaspaliste = new KaspalisteApp(dbname);
    kaspaliste->show();

   }

  return app.exec();


	}	catch(KaspaErr& err) {
    err.print();
    // QMessageBox::warning(0L, i18n("Error"), err.error());
		return 1;
  }	
}
